# wordslab-notebooks-lib


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Introduction

[wordslab-notebooks-lib](https://github.com/wordslab-org/wordslab-notebooks-lib)
is a companion library for
[wordslab-notebooks](https://github.com/wordslab-org/wordslab-notebooks?tab=readme-ov-file#wordslab-notebooks).

**wordslab-notebooks** is a one click install of all the tools you need
to learn, explore and build AI applications on your own machine. -
Recent and compatible versions of the best open source tools - Optimized
work environment to save disk space and memory - Options to leverage
your own machines at home or to rent more powerful machines in the
cloud - Documentation to guide you in your AI learning and exploration
journey

3 main applications - A rich chat interface (text, images, voice) : Open
WebUI - A notebooks platform (text & code) : JupyterJab + Jupyter AI
extension - A development environment (code) : Visual Studio Code +
Continue.dev extension + Aider terminal agent

Fully integrated AI environment with - A visual dashboard to help you
navigate all applications and manage your machine resources - Optimized
inference engines to run AI models : Ollama + vLLM

**wordslab-notebooks-lib** is meant to be used in Jupyterlab notebooks
or python programs running inside the wordslab-notebooks environment.

It provides many helper functions to easily access and use all the
applications and resources of the environment.

## Getting started

### Installation

``` sh
$ pip install wordslab_notebooks_lib
```

### Documentation

Please read the documentation to discover all the features of the
library:

https://wordslab-org.github.io/wordslab-notebooks-lib/

### First steps

The
[`WordslabNotebooks`](https://wordslab-org.github.io/wordslab-notebooks-lib/core.html#wordslabnotebooks)
class is the main entrypoint to discover all wordslab-notebooks
resources.

``` python
from wordslab_notebooks_lib.core import *

wlnb = WordslabNotebooks()
```

wordslab-notebooks version

``` python
wlnb.version
```

    '2025-11'

wordslab-notebooks external urls

``` python
wlnb.url_dashboard
```

    'http://192.168.1.197:8888'

``` python
wlnb.url_userapp1
```

    'https://192.168.1.197:8883'

wordslab-notebooks internal ports

``` python
wlnb.port_ollama
```

    11434

``` python
wlnb.port_userapp1
```

    '8883'

wordslab-notebooks install directories

``` python
wlnb.dir_scripts
```

    '/home/wordslab-notebooks-2025-11'

``` python
wlnb.dir_workspace
```

    '/home/workspace'

wordslab-notebooks applications data directories

``` python
wlnb.dir_openwebui_data
```

    '/home/workspace/.openwebui'

``` python
wlnb.dir_jupyterlab_data
```

    '/home/workspace/.jupyter'

wordslab-notebooks models directories

``` python
wlnb.dir_models_ollama
```

    '/home/models/ollama'

``` python
wlnb.dir_models_vllm
```

    '/home/models/huggingface'

wordslab-notebooks default models

``` python
wlnb.default_model_chat
```

    'gemma3:27b'

``` python
wlnb.default_model_code
```

    'qwen3:30b'
